local T, C, L, _ = unpack(select(2, ...))

----------------------------------------------------------------------------------------
--	Fix Enter Battle Button
----------------------------------------------------------------------------------------
PVPReadyDialog.enterButton:Hide()
local Button = CreateFrame("Button", "EnterBattleButton", PVPReadyDialog, "UIPanelButtonTemplate, SecureActionButtonTemplate")
Button:SetSize(128, 21)
Button:SetPoint("BOTTOMRIGHT", PVPReadyDialog, "BOTTOM", -7, 17)
Button:SetAttribute("type", "macro")

local Update = function()
	for i = 1, GetMaxBattlefieldID() do
        local status = GetBattlefieldStatus(i)
        local time = GetBattlefieldPortExpiration(i)
        if status == "confirm" then
        	Button:SetAttribute("macrotext", "/click MiniMapBattlefieldFrame RightButton\n" ..
            "/click DropDownList1Button" .. ((i * 3) - 1))
            Button:SetText(ENTER_BATTLE .. "(" .. time .. ")")
        end
        if status == "active" then
        	PVPReadyDialog:Hide()
        end
    end
end

PVPReadyDialog:SetScript("OnUpdate", Update)

----------------------------------------------------------------------------------------
--	NOOP functions not found in some versions of Classic
----------------------------------------------------------------------------------------
if not IsFlying then
	IsFlying = T.dummy
end

if not UnitInVehicle then
	UnitInVehicle = T.dummy
end

----------------------------------------------------------------------------------------
--	Specialization Functions
----------------------------------------------------------------------------------------
function T.GetSpecialization()
	local specIndex
	local max = 0
	for tabIndex = 1, GetNumTalentTabs() do
		local spent = select(3, GetTalentTabInfo(tabIndex))
		if spent >= max then
			specIndex = tabIndex
			max = spent
		end
	end
	return specIndex
end

local isCaster = {
	DRUID = {true},					-- Balance
	HUNTER = {nil, nil, nil},
	MAGE = {true, true, true},
	PALADIN = {nil, nil, nil},
	PRIEST = {nil, nil, true},		-- Shadow
	ROGUE = {nil, nil, nil},
	SHAMAN = {true},				-- Elemental
	WARLOCK = {true, true, true},
	WARRIOR = {nil, nil, nil}
}

function T.GetSpecializationRole()
	local tree = T.GetSpecialization()
	-- eventually check for tank stats in case a tanking in a non-traditional spec (mostly for warriors)
	if (T.class == "PALADIN" and tree == 2) or (T.class == "WARRIOR" and (tree == 3 or GetBonusBarOffset() == 2)) or (T.class == "DRUID" and tree == 2 and GetBonusBarOffset() == 3) or (T.class == "DEATHKNIGHT" and AuraUtil.FindAuraByName(GetSpellInfo(48263), "player")) then
		return "TANK"
	elseif (T.class == "PALADIN" and tree == 1) or (T.class == "DRUID" and tree == 3) or (T.class == "SHAMAN" and tree == 3) or (T.class == "PRIEST" and tree ~= 3) then
		return "HEALER"
	else
		local base, posBuff, negBuff = UnitAttackPower("player")

		local current = {}
		local best = 1
		for i = 1, 7 do
			current[i] = GetSpellBonusDamage(i)
			if current[i] > current[best] then
				best = i
			end
		end

		local ap = base + posBuff + negBuff
		local spell = GetSpellBonusDamage(best)
		local heal = GetSpellBonusHealing()

		if T.class ~= "HUNTER" and heal >= ap and heal >= spell then
			return "HEALER" -- healing gear without having the majority of talents in a healing tree
		elseif T.class ~= "HUNTER" and (isCaster[T.class][tree] or spell >= ap) then
			return "CASTER" -- ordinarily "DAMAGER"
		else
			return "MELEE" -- ordinarily "DAMAGER"
		end
	end
end

-- Add later
if not GetAverageItemLevel then
	GetAverageItemLevel = function()
		local slotName = {
			"HeadSlot", "NeckSlot", "ShoulderSlot", "BackSlot", "ChestSlot", "WristSlot",
			"HandsSlot", "WaistSlot", "LegsSlot", "FeetSlot", "Finger0Slot", "Finger1Slot",
			"Trinket0Slot", "Trinket1Slot", "MainHandSlot", "SecondaryHandSlot", "RangedSlot", "AmmoSlot"
		}

		local total, slot, itn, level = 0, 0, 0, 0

		for i in pairs(slotName) do
			slot = GetInventoryItemLink("player", GetInventorySlotInfo(slotName[i]))
			if slot then
				itn = itn + 1
				level = select(4, GetItemInfo(slot)) or 0
				total = total + level
			end
		end

		if total < 1 or itn < 1 then return 0 end

		return floor(total / itn * 10) / 10, floor(total / itn * 10) / 10
	end
end

----------------------------------------------------------------------------------------
--	Threat Functions
----------------------------------------------------------------------------------------
local threatColors = {
	[0] = {0.69, 0.69, 0.69},
	[1] = {1, 1, 0.47},
	[2] = {1, 0.6, 0},
	[3] = {1, 0, 0}
}

if not GetThreatStatusColor then
	GetThreatStatusColor = _G.GetThreatStatusColor or function(statusIndex)
		if not (type(statusIndex) == "number" and statusIndex >= 0 and statusIndex < 4) then
			statusIndex = 0
		end

		return threatColors[statusIndex][1], threatColors[statusIndex][2], threatColors[statusIndex][3]
	end
end

----------------------------------------------------------------------------------------
--	Getspellid Functions
----------------------------------------------------------------------------------------
function T.GetSpellID(spellName, unit, auraType)
	-- change localized MELEE string into the appropriate spellID
	if spellName == MELEE then
		return 6603
	-- get spellID from auras
	elseif auraType and unit then
		if auraType == AURA_TYPE_DEBUFF then
			return select(10, AuraUtil.FindAuraByName(spellName, unit, "HARMFUL")) or 0
		else
			return select(10, AuraUtil.FindAuraByName(spellName, unit)) or 0
		end
	-- get spellID from lookup/spellbook
	else
		-- eventually build a cache from UNIT_SPELLCAST_* events to track lower ranks
		-- for now, we just assume max rank and get that spellID from the spellbook
		local spellID = spellLookupLocalized[spellName]
		if not spellID then
			spellID = select(7, GetSpellInfo(spellName))
		end

		return spellID or 0
	end
end
