local T, C, L, _ = unpack(select(2, ...))
if C.skins.blizzard_frames ~= true then return end

----------------------------------------------------------------------------------------
--	Quest skin
----------------------------------------------------------------------------------------
local function LoadSkin()
	QuestFrame:CreateBackdrop("Transparent")
	QuestFrame.backdrop:SetPoint("TOPLEFT", 10, -12)
	QuestFrame.backdrop:SetPoint("BOTTOMRIGHT", -32, 76)

	QuestFrameNpcNameText:ClearAllPoints()
	QuestFrameNpcNameText:SetPoint("TOP", QuestFrame.backdrop, "TOP", 0, -6)

	T.SkinCloseButton(QuestFrameCloseButton, QuestFrame.backdrop)

	local ScrollFrames = {
		"QuestDetailScrollFrame",
		"QuestRewardScrollFrame",
		"QuestProgressScrollFrame",
		"QuestGreetingScrollFrame",
	}

	for _, object in pairs(ScrollFrames) do
		_G[object]:ClearAllPoints()
		_G[object]:SetPoint("TOP", QuestFrame.backdrop, -6, -30)
		_G[object]:SetHeight(362)
	end

	local QuestStrip = {
		"QuestFrame",
		"QuestFrameDetailPanel",
		"QuestDetailScrollFrame",
		"QuestDetailScrollChildFrame",
		"QuestRewardScrollFrame",
		"QuestRewardScrollChildFrame",
		"QuestProgressScrollFrame",
		"QuestGreetingScrollFrame",
		"QuestFrameProgressPanel",
		"QuestFrameRewardPanel",
	}

	for _, object in pairs(QuestStrip) do
		_G[object]:StripTextures(true)
	end

	QuestFrameDetailPanel:SetPoint("TOPLEFT", -5, -12)
	QuestFrameDetailPanel:SetPoint("BOTTOMRIGHT", 0, 76)
	QuestFrameProgressPanel:SetPoint("TOPLEFT", -5, -12)
	QuestFrameProgressPanel:SetPoint("BOTTOMRIGHT", 0, 76)

	local LeftQuestButtons = {
		"QuestFrameAcceptButton",
		"QuestFrameCompleteButton",
		"QuestFrameCompleteQuestButton",
	}

	local RightQuestButtons = {
		"QuestFrameDeclineButton",
		"QuestFrameGoodbyeButton",
		"QuestFrameCancelButton",
	}

	for _, button in pairs(LeftQuestButtons) do
		_G[button]:SkinButton()
		_G[button]:SetPoint("BOTTOMLEFT", QuestFrame.backdrop, "BOTTOMLEFT", 4, 4)
	end

	for _, button in pairs(RightQuestButtons) do
		_G[button]:SkinButton()
		_G[button]:SetPoint("BOTTOMRIGHT", QuestFrame.backdrop, "BOTTOMRIGHT", -4, 4)
	end

	local ScrollBars = {
		"QuestDetailScrollFrameScrollBar",
		"QuestProgressScrollFrameScrollBar",
		"QuestRewardScrollFrameScrollBar",
		"QuestGreetingScrollFrameScrollBar",
		"QuestNPCModelTextScrollFrameScrollBar",
	}

	for _, scrollbar in pairs(ScrollBars) do
		T.SkinScrollBar(_G[scrollbar])
	end

	QuestInfoTitleHeader:SetTextColor(1, 0.8, 0)
	QuestInfoTitleHeader:SetShadowColor(0, 0, 0)
	QuestInfoDescriptionText:SetTextColor(1, 1, 1)
	QuestInfoObjectivesHeader:SetTextColor(1, 0.8, 0)
	QuestInfoObjectivesHeader:SetShadowColor(0, 0, 0)
	QuestInfoObjectivesText:SetTextColor(1, 1, 1)
	QuestInfoRewardText:SetTextColor(1, 1, 1)
	QuestInfoRewardsFrame.Header:SetTextColor(1, 0.8, 0)
	QuestInfoRewardsFrame.Header:SetShadowColor(0, 0, 0)
	QuestInfoRewardsFrame.ItemChooseText:SetTextColor(1, 1, 1)
	QuestInfoRewardsFrame.ItemReceiveText:SetTextColor(1, 1, 1)

	local function SkinReward(button, mapReward)
		if button.NameFrame then button.NameFrame:Hide() end
		if button.CircleBackground then button.CircleBackground:Hide() end
		if button.CircleBackgroundGlow then button.CircleBackgroundGlow:Hide() end
		if button.ValueText then button.ValueText:SetPoint("BOTTOMRIGHT", button.Icon, 0, 0) end
		if button.IconBorder then button.IconBorder:SetAlpha(0) end
		button.Icon:SetTexCoord(0.1, 0.9, 0.1, 0.9)
		button:CreateBackdrop("Default")
		button.backdrop:ClearAllPoints()
		button.backdrop:SetPoint("TOPLEFT", button, -2, 2)
		button.backdrop:SetPoint("BOTTOMRIGHT", button, -4, 0)
		if mapReward then
			button.Icon:SetSize(26, 26)
		end
	end

	local function GetItemBorderColor(r, g, b)
		local numQuestRewards, numQuestChoices, quality
		if QuestInfoFrame.questLog then
			numQuestRewards, numQuestChoices = GetNumQuestLogRewards(), GetNumQuestLogChoices() or GetNumQuestLogChoices(C_QuestLog.GetSelectedQuest(), true)
		else
			numQuestRewards, numQuestChoices = GetNumQuestRewards(), GetNumQuestChoices()
		end

		local totalRewards = numQuestRewards + numQuestChoices
		if totalRewards == 0 then return end

		if numQuestChoices > 0 then
			for i = 1, numQuestChoices do
				local button = _G["QuestInfoRewardsFrameQuestInfoItem"..i]
				if button then
					if QuestInfoFrame.questLog then
						quality = select(4, GetQuestLogChoiceInfo(i))
					else
						quality = select(4, GetQuestItemInfo("choice", i))
					end
				end
			end
		end

		if numQuestRewards > 0 then
			for i = 1, numQuestRewards do
				local button = _G["QuestInfoRewardsFrameQuestInfoItem"..i]
				if button then
					if QuestInfoFrame.questLog then
						quality = select(4, GetQuestLogChoiceInfo(i))
					else
						quality = select(4, GetQuestItemInfo("reward", i))
					end
				end
			end
		end

		local r, g, b = GetItemQualityColor(quality)

		return r, g, b
	end

	hooksecurefunc("QuestInfo_GetRewardButton", function(rewardsFrame, index)
		local button = rewardsFrame.RewardButtons[index]
		local r, g, b = GetItemBorderColor()
		SkinReward(button, rewardsFrame == MapQuestInfoRewardsFrame)
		button.backdrop:SetBackdropBorderColor(r, g, b)
		button.Name:SetTextColor(r, g, b)
	end)

	hooksecurefunc("QuestInfoItem_OnClick", function(self)
		QuestInfoItemHighlight:StripTextures()
		QuestInfoItemHighlight:SetTemplate("Default")
		QuestInfoItemHighlight:SetBackdropBorderColor(0, 0, 0, 0)
		QuestInfoItemHighlight:SetBackdropColor(1, 1, 0, 0.25)
		QuestInfoItemHighlight:ClearAllPoints()
		QuestInfoItemHighlight:SetPoint("TOPLEFT", self.Name, "TOPLEFT", -3, 1)
		QuestInfoItemHighlight:SetPoint("BOTTOMRIGHT", self.Name, "BOTTOMRIGHT", 6, -1)
	end)

	for i = 1, 6 do
		local button = _G["QuestProgressItem"..i]
		local texture = _G["QuestProgressItem"..i.."IconTexture"]

		if button.NameFrame then button.NameFrame:Hide() end
		button.Name:SetFont(C.media.normal_font, 12)

		button:CreateBackdrop("Default")
		button.backdrop:ClearAllPoints()
		button.backdrop:SetPoint("TOPLEFT", texture, -2, 2)
		button.backdrop:SetPoint("BOTTOMRIGHT", texture, 2, -2)

		texture:SetTexCoord(0.1, 0.9, 0.1, 0.9)

		button.backdrop:SetBackdropBorderColor(1, 1, 0)
	end

	hooksecurefunc("QuestFrameProgressItems_Update", function()
		QuestProgressTitleText:SetTextColor(1, 0.8, 0)
		QuestProgressTitleText:SetShadowColor(0, 0, 0)
		QuestProgressText:SetTextColor(1, 1, 1)
		QuestProgressRequiredItemsText:SetTextColor(1, 0.8, 0)
		QuestProgressRequiredItemsText:SetShadowColor(0, 0, 0)
		QuestProgressRequiredMoneyText:SetTextColor(1, 0.8, 0)
	end)

	-- QuestGreeting
	local function UpdateGreetingPanel()
		QuestFrameGreetingPanel:StripTextures()
		QuestFrameGreetingGoodbyeButton:SkinButton()
		QuestFrameGreetingGoodbyeButton:SetPoint("BOTTOMRIGHT", QuestFrame.backdrop, "BOTTOMRIGHT", -4, 4)
		GreetingText:SetTextColor(1, 1, 1)
		CurrentQuestsText:SetTextColor(1, 0.8, 0)
		AvailableQuestsText:SetTextColor(1, 0.8, 0)
		QuestGreetingFrameHorizontalBreak:Kill()

		for i = 1, MAX_NUM_QUESTS do
			local button = _G["QuestTitleButton"..i]

			if button:GetFontString() then
				if button:GetFontString():GetText() and button:GetFontString():GetText():find("|cff000000") then
					button:GetFontString():SetText(string.gsub(button:GetFontString():GetText(), "|cff000000", "|cffFFFF00"))
				end
			end
		end
	end

	QuestFrameGreetingPanel:HookScript("OnShow", UpdateGreetingPanel)
	hooksecurefunc("QuestFrameGreetingPanel_OnShow", UpdateGreetingPanel)
end

tinsert(T.SkinFuncs["ShestakUI"], LoadSkin)
